@@ -12,7 +12,7 @@ import logging
 import re
 from typing import Any, List, Optional
 
-from .const import DEV_REGEX_ANY, HGI_DEVICE_ID, NON_DEVICE_ID, __dev_mode__
+from .const import __dev_mode__  # DEVICE_ID_REGEX,
 from .protocol import RAMSES_CODES, Command, ExpiredCallbackError, Priority
 from .protocol.opentherm import OTB_MSG_IDS
 
@@ -30,6 +30,7 @@ from .protocol import (  # noqa: F401, isort: skip
     _000E,
     _0016,
     _0100,
+    _0150,
     _01D0,
     _01E9,
     _0404,
@@ -40,7 +41,9 @@ from .protocol import (  # noqa: F401, isort: skip
     _1060,
     _1081,
     _1090,
+    _1098,
     _10A0,
+    _10B0,
     _10E0,
     _10E1,
     _1100,
@@ -52,10 +55,12 @@ from .protocol import (  # noqa: F401, isort: skip
     _12B0,
     _12C0,
     _12C8,
+    _12F0,
     _1300,
     _1F09,
     _1F41,
     _1FC9,
+    _1FD0,
     _1FD4,
     _2249,
     _22C9,
@@ -65,6 +70,11 @@ from .protocol import (  # noqa: F401, isort: skip
     _22F3,
     _2309,
     _2349,
+    _2389,
+    _2400,
+    _2401,
+    _2410,
+    _2420,
     _2D49,
     _2E04,
     _30C9,
@@ -77,6 +87,8 @@ from .protocol import (  # noqa: F401, isort: skip
     _3200,
     _3210,
     _3220,
+    _3221,
+    _3223,
     _3B00,
     _3EF0,
     _3EF1,
@@ -94,9 +106,11 @@ SCAN_FULL = "scan_full"
 SCAN_HARD = "scan_hard"
 SCAN_XXXX = "scan_xxxx"
 
-DEVICE_ID_REGEX = re.compile(DEV_REGEX_ANY)
+# DEVICE_ID_REGEX = re.compile(DEVICE_ID_REGEX.ANY)
 
 QOS_DEFAULT = {"priority": Priority.LOW, "retries": 0}
+QOS_DEFAULT_HIGH = {"priority": Priority.HIGH, "retries": 3}
+QOS_DEFAULT_LOW = {"priority": Priority.LOW, "retries": 3}
 QOS_DEFAULT_SCAN = {"priority": Priority.LOW, "retries": 0, "disable_backoff": True}
 
 DEV_MODE = __dev_mode__ and False
@@ -109,15 +123,11 @@ if DEV_MODE:
 def script_decorator(fnc):
     def wrapper(gwy, *args, **kwargs) -> Optional[Any]:
 
-        gwy.send_cmd(
-            Command._puzzle(message="Script begins:", priority=Priority.HIGH, retries=3)
-        )
+        gwy.send_cmd(Command._puzzle(message="Script begins:", **QOS_DEFAULT_HIGH))
 
         result = fnc(gwy, *args, **kwargs)
 
-        gwy.send_cmd(
-            Command._puzzle(message="Script done.", priority=Priority.LOWEST, retries=3)
-        )
+        gwy.send_cmd(Command._puzzle(message="Script done.", **QOS_DEFAULT_LOW))
 
         return result
 
@@ -129,7 +139,7 @@ def spawn_scripts(gwy, **kwargs) -> List[asyncio.Task]:
     tasks = []
 
     if kwargs.get(EXEC_CMD):
-        spawn_exec_cmd(gwy, **kwargs)  # TODO: wrap in a try?
+        tasks += [gwy._loop.create_task(exec_cmd(gwy, **kwargs))]
 
     if kwargs.get(GET_FAULTS):
         tasks += [gwy._loop.create_task(get_faults(gwy, kwargs[GET_FAULTS]))]
@@ -140,7 +150,7 @@ def spawn_scripts(gwy, **kwargs) -> List[asyncio.Task]:
     elif kwargs.get(SET_SCHED) and kwargs[SET_SCHED][0]:
         tasks += [gwy._loop.create_task(set_schedule(gwy, *kwargs[SET_SCHED]))]
 
-    elif kwargs[EXEC_SCR]:
+    elif kwargs.get(EXEC_SCR):
         script = SCRIPTS.get(f"{kwargs[EXEC_SCR][0]}")
         if script is None:
             _LOGGER.warning(f"Script: {kwargs[EXEC_SCR][0]}() - unknown script")
@@ -152,41 +162,15 @@ def spawn_scripts(gwy, **kwargs) -> List[asyncio.Task]:
     return tasks
 
 
-def spawn_exec_cmd(gwy, **kwargs):
+async def exec_cmd(gwy, **kwargs):
 
-    if not kwargs.get(EXEC_CMD):  # e.g. "RQ 01:145038 1F09 00"
-        _LOGGER.warning("Execute: Command is invalid: '%s'", kwargs)
-        return
+    # if not kwargs.get(EXEC_CMD):  # e.g. "RQ 01:145038 1F09 00"
+    #     _LOGGER.warning("Execute: Command is invalid: '%s'", kwargs)
+    #     return
 
-    cmd = kwargs[EXEC_CMD].upper().split()
-    if len(cmd) < 4:
-        _LOGGER.warning("Execute: Command is invalid: '%s'", kwargs)
-        return
+    cmd = Command.from_str(kwargs[EXEC_CMD], **QOS_DEFAULT_HIGH)
 
-    verb = cmd.pop(0)
-    seqn = "---" if DEVICE_ID_REGEX.match(cmd[0]) else cmd.pop(0)
-    payload = cmd.pop()[:48]
-    code = cmd.pop()
-
-    if not 0 < len(cmd) < 4:
-        _LOGGER.warning("Execute: Command is invalid: '%s'", kwargs)
-        return
-    elif len(cmd) == 1:
-        addrs = (HGI_DEVICE_ID, cmd[0], NON_DEVICE_ID)
-    elif len(cmd) == 3:
-        addrs = (cmd[0], cmd[1], cmd[2])
-    elif cmd[0] == cmd[1]:
-        addrs = (cmd[0], NON_DEVICE_ID, cmd[1])
-    else:
-        addrs = (cmd[0], cmd[1], NON_DEVICE_ID)
-
-    qos = {"priority": Priority.HIGH, "retries": 3}
-    try:
-        kmd = Command.packet(verb, code, payload, *addrs, seqn=seqn, **qos)
-    except ValueError as exc:
-        _LOGGER.warning("Execute: Command is invalid: '%s' (%s)", kwargs[EXEC_CMD], exc)
-    else:
-        gwy.send_cmd(kmd)
+    await gwy.async_send_cmd(cmd)
 
 
 async def periodic(gwy, cmd, count=1, interval=None):
@@ -321,7 +305,7 @@ async def script_scan_full(gwy, dev_id: str):
 
     # these are possible/difficult codes
     qos = {"priority": Priority.DEFAULT, "retries": 2}
-    for code in ("0150", "2389"):
+    for code in (_0150, _2389):
         gwy.send_cmd(Command(RQ, code, "0000", dev_id, **qos))
 
 
@@ -329,6 +313,17 @@ async def script_scan_full(gwy, dev_id: str):
 async def script_scan_hard(gwy, dev_id: str):
     _LOGGER.warning("scan_hard() invoked - expect some Warnings")
 
+    # def callback(msg) -> None:
+    #     nonlocal code
+
+    #     if (code := code + 1) < 0x4000:
+    #         cmd = Command(RQ, f"{code:04X}", "0000", dev_id, **QOS_DEFAULT_SCAN)
+    #         # gwy.msg_protocol.send_data(cmd, callback=callback)
+    #         gwy.send_cmd(cmd, callback=callback)
+
+    # code = 0x0000
+    # callback(None)
+
     for code in range(0x4000):
         gwy.send_cmd(Command(RQ, f"{code:04X}", "0000", dev_id, **QOS_DEFAULT_SCAN))
         await asyncio.sleep(1)
@@ -412,11 +407,11 @@ async def script_scan_otb_ramses(gwy, dev_id: str):  # Tested only upon a R8820A
         _042F,
         _10E0,  # device_info
         _10E1,  # device_id
-        "1FD0",
-        "2400",
-        "2401",
-        "2410",
-        "2420",
+        _1FD0,
+        _2400,
+        _2401,
+        _2410,
+        _2420,
         _1300,  # cv water pressure      / CHWaterPressure
         _1081,  # max ch setpoint        / MaxCHWaterSetpoint
         _10A0,  # dhw params["setpoint"] / DHWSetpoint
@@ -425,12 +420,12 @@ async def script_scan_otb_ramses(gwy, dev_id: str):  # Tested only upon a R8820A
         _1290,  # outdoor temp           / OutsideTemperature
         _3200,  # boiler output temp     / BoilerWaterTemperature
         _3210,  # boiler return temp     / ReturnWaterTemperature
-        "0150",
-        "12F0",  # DHW flow rate?
-        "1098",
-        "10B0",
-        "3221",
-        "3223",
+        _0150,
+        _12F0,  # DHW flow rate?
+        _1098,
+        _10B0,
+        _3221,
+        _3223,
         _3EF0,  # rel. modulation level  / RelativeModulationLevel (also, below)
         _3EF1,  # rel. modulation level  / RelativeModulationLevel
     )  # excl. 3220
