@@ -11,6 +11,7 @@ from typing import Optional, Tuple, Union
 
 from .address import Address
 from .const import NON_DEVICE_ID, NUL_DEVICE_ID
+from .exceptions import InvalidPayloadError
 from .ramses import (
     CODE_IDX_COMPLEX,
     CODE_IDX_DOMAIN,
@@ -36,6 +37,7 @@ from .const import (  # noqa: F401, isort: skip
     _000E,
     _0016,
     _0100,
+    _0150,
     _01D0,
     _01E9,
     _0404,
@@ -44,9 +46,13 @@ from .const import (  # noqa: F401, isort: skip
     _0B04,
     _1030,
     _1060,
+    _1081,
     _1090,
+    _1098,
     _10A0,
+    _10B0,
     _10E0,
+    _10E1,
     _1100,
     _1260,
     _1280,
@@ -56,9 +62,12 @@ from .const import (  # noqa: F401, isort: skip
     _12B0,
     _12C0,
     _12C8,
+    _12F0,
+    _1300,
     _1F09,
     _1F41,
     _1FC9,
+    _1FD0,
     _1FD4,
     _2249,
     _22C9,
@@ -68,6 +77,11 @@ from .const import (  # noqa: F401, isort: skip
     _22F3,
     _2309,
     _2349,
+    _2389,
+    _2400,
+    _2401,
+    _2410,
+    _2420,
     _2D49,
     _2E04,
     _30C9,
@@ -77,7 +91,11 @@ from .const import (  # noqa: F401, isort: skip
     _31D9,
     _31DA,
     _31E0,
+    _3200,
+    _3210,
     _3220,
+    _3221,
+    _3223,
     _3B00,
     _3EF0,
     _3EF1,
@@ -384,10 +402,12 @@ def _pkt_idx(pkt) -> Union[str, bool, None]:  # _has_array, _has_ctl
 
     # mutex 1/4, CODE_IDX_NONE: always returns False
     if pkt.code in CODE_IDX_NONE:  # returns False
-        assert (
-            RAMSES_CODES[pkt.code].get(pkt.verb, "")[:3] != "^00"
-            or pkt.payload[:2] == "00"
-        ), f"{pkt} # index is {pkt.payload[:2]}, expecting 00"
+        if RAMSES_CODES[pkt.code].get(pkt.verb, "")[:3] == "^00" and (
+            pkt.payload[:2] != "00"
+        ):
+            raise InvalidPayloadError(
+                f"Packet idx is {pkt.payload[:2]}, but expecting no idx (00)"
+            )
         return False
 
     # mutex 3/4, CODE_IDX_SIMPLE: potentially some false -ves?
@@ -396,9 +416,10 @@ def _pkt_idx(pkt) -> Union[str, bool, None]:  # _has_array, _has_ctl
 
     # TODO: is this needed?: exceptions to CODE_IDX_SIMPLE
     if pkt.payload[:2] in ("F8", "F9", "FA", "FC"):  # TODO: FB, FD
-        assert (
-            pkt.code in CODE_IDX_DOMAIN
-        ), f"Payload index is {pkt.payload[:2]}, not expecting a domain_id"
+        if pkt.code not in CODE_IDX_DOMAIN:
+            raise InvalidPayloadError(
+                f"Packet idx is {pkt.payload[:2]}, but not expecting a domain id"
+            )
         return pkt.payload[:2]
 
     if pkt._has_ctl:  # risk of false -ves, TODO: pkt.src.type == "18" too?  # DEX
@@ -409,8 +430,9 @@ def _pkt_idx(pkt) -> Union[str, bool, None]:  # _has_array, _has_ctl
         return pkt.payload[:2]  # pkt._gwy.config.max_zones checked elsewhere
 
     if pkt.payload[:2] != "00":
-        _LOGGER.warning(f"{pkt} # Expecting payload index to be 00")  # return None?
-        return pkt.payload[:2]
+        raise InvalidPayloadError(
+            f"Packet idx is {pkt.payload[:2]}, but expecting no idx (00)"
+        )
 
     if pkt.code in CODE_IDX_SIMPLE:
         return  # False  # TODO: return None (less precise) or risk false -ves?
