@@ -40,6 +40,7 @@ from .const import (  # noqa: F401, isort: skip, pylint: disable=unused-import
     _000E,
     _0016,
     _0100,
+    _0150,
     _01D0,
     _01E9,
     _0404,
@@ -48,9 +49,13 @@ from .const import (  # noqa: F401, isort: skip, pylint: disable=unused-import
     _0B04,
     _1030,
     _1060,
+    _1081,
     _1090,
+    _1098,
     _10A0,
+    _10B0,
     _10E0,
+    _10E1,
     _1100,
     _1260,
     _1280,
@@ -60,9 +65,12 @@ from .const import (  # noqa: F401, isort: skip, pylint: disable=unused-import
     _12B0,
     _12C0,
     _12C8,
+    _12F0,
+    _1300,
     _1F09,
     _1F41,
     _1FC9,
+    _1FD0,
     _1FD4,
     _2249,
     _22C9,
@@ -72,6 +80,11 @@ from .const import (  # noqa: F401, isort: skip, pylint: disable=unused-import
     _22F3,
     _2309,
     _2349,
+    _2389,
+    _2400,
+    _2401,
+    _2410,
+    _2420,
     _2D49,
     _2E04,
     _30C9,
@@ -81,7 +94,11 @@ from .const import (  # noqa: F401, isort: skip, pylint: disable=unused-import
     _31D9,
     _31DA,
     _31E0,
+    _3200,
+    _3210,
     _3220,
+    _3221,
+    _3223,
     _3B00,
     _3EF0,
     _3EF1,
@@ -92,7 +109,7 @@ from .const import (  # noqa: F401, isort: skip, pylint: disable=unused-import
 _TD_SECONDS_000 = td(seconds=0)
 _TD_SECONDS_003 = td(seconds=3)
 _TD_SECONDS_360 = td(seconds=360)
-_TD_MINUTES_003 = td(minutes=3)
+_TD_MINUTES_005 = td(minutes=5)
 _TD_MINUTES_060 = td(minutes=60)
 
 
@@ -277,7 +294,7 @@ def pkt_timeout(pkt) -> Optional[td]:  # NOTE: import OtbGateway ??
             return PARAMS_MSG_IDS[pkt.payload[4:6]]
         if pkt.payload[4:6] in STATUS_MSG_IDS:
             return STATUS_MSG_IDS[pkt.payload[4:6]]
-        return _TD_MINUTES_003
+        return _TD_MINUTES_005
 
     # if pkt.code in (_3B00, _3EF0, ):  # TODO: 0008, 3EF0, 3EF1
     #     return td(minutes=6.7)  # TODO: WIP
