@@ -6,7 +6,7 @@
 import logging
 from datetime import timedelta as td
 
-from .const import DEV_KLASS, DEVICE_TYPE_BY_CLASS
+from .const import DEV_KLASS
 
 from .const import I_, RP, RQ, W_, __dev_mode__  # noqa: F401, isort: skip
 
@@ -40,6 +40,7 @@ from .const import (  # noqa: F401, isort: skip
     _10E0,
     _10E1,
     _1100,
+    _11F0,
     _1260,
     _1280,
     _1290,
@@ -53,6 +54,7 @@ from .const import (  # noqa: F401, isort: skip
     _1F09,
     _1F41,
     _1FC9,
+    _1FCA,
     _1FD0,
     _1FD4,
     _2249,
@@ -88,7 +90,7 @@ from .const import (  # noqa: F401, isort: skip
     _PUZZ,
 )
 
-DEV_MODE = True or __dev_mode__
+DEV_MODE = __dev_mode__
 
 _LOGGER = logging.getLogger(__name__)
 if DEV_MODE:
@@ -170,7 +172,7 @@ RAMSES_CODES = {  # rf_unknown
         RQ: r"^0[0-9A-F][01][0-9A-F]$",  # TODO: f"{zone_idx}{device_type}"
         EXPIRES: False,
     },
-    _000E: {  # unknown
+    _000E: {  # unknown_000e
         NAME: "message_000e",
         I_: r"^000014$",
     },
@@ -185,19 +187,19 @@ RAMSES_CODES = {  # rf_unknown
         RP: r"^00[0-9A-F]{4}F{4}$",
         EXPIRES: td(days=1),  # TODO: make longer?
     },
-    _0150: {  # unknown
+    _0150: {  # unknown_0150
         NAME: "message_0150",
         RQ: r"^00$",
-        RP: r"^00",
+        RP: r"^000000$",
     },
-    _01D0: {  # TODO: not well understood, definitely a real code, zone_idx is a guess
+    _01D0: {  # unknown_01d0, TODO: definitely a real code, zone_idx is a guess
         NAME: "message_01d0",
         I_: r"^0[0-9A-F][0-9A-F]{2}$",
         W_: r"^0[0-9A-F][0-9A-F]{2}$",
         #  W --- 04:000722 01:158182 --:------ 01D0 002 0003  # is a guess, the
         #  I --- 01:158182 04:000722 --:------ 01D0 002 0003  # TRV was in zone 00
     },
-    _01E9: {  # TODO: not well understood, definitely a real code, zone_idx is a guess
+    _01E9: {  # unknown_01e9, TODO: definitely a real code, zone_idx is a guess
         NAME: "message_01e9",
         I_: r"^0[0-9A-F][0-9A-F]{2}$",
         W_: r"^0[0-9A-F][0-9A-F]{2}$",
@@ -217,7 +219,7 @@ RAMSES_CODES = {  # rf_unknown
         I_: r"^00(00|40|C0)[0-3][0-9A-F]B0[0-9A-F]{6}0000[0-9A-F]{12}FFFF700[012][0-9A-F]{6}$",
         RQ: r"^0000[0-3][0-9A-F]$",  # f"0000{log_idx}", no payload
     },
-    _042F: {  # unknown, # non-evohome are len==9, seen only once?
+    _042F: {  # unknown_042f, # non-evohome are len==9, seen only once?
         # .I --- 32:168090 --:------ 32:168090 042F 009 000000100F00105050
         # RP --- 10:048122 18:006402 --:------ 042F 009 000200001400163010
         NAME: "message_042f",
@@ -225,7 +227,7 @@ RAMSES_CODES = {  # rf_unknown
         RQ: r"^00$",
         RP: r"^00([0-9A-F]{2}){7,8}$",
     },
-    _0B04: {  # unknown
+    _0B04: {  # unknown_0b04
         #  I --- --:------ --:------ 12:207082 0B04 002 00C8
         NAME: "message_0b04",
         I_: r"^00(00|C8)$",
@@ -245,20 +247,15 @@ RAMSES_CODES = {  # rf_unknown
         RQ: r"^00$",
         RP: r"^00[0-9A-F]{4}$",
     },
-    _1090: {  # unknown
+    _1090: {  # unknown_1090
         NAME: "message_1090",
         # RQ: r"^00$",  # TODO:
     },
-    _1098: {  # unknown
+    _1098: {  # unknown_1098
         NAME: "message_1098",
         RQ: r"^00$",
         RP: r"^00",
     },
-    _10B0: {  # unknown
-        NAME: "message_10b0",
-        RQ: r"^00$",
-        RP: r"^00",
-    },
     _10A0: {  # dhw_params
         NAME: "dhw_params",
         # RQ --- 07:045960 01:145038 --:------ 10A0 006 0013740003E4
@@ -270,6 +267,11 @@ RAMSES_CODES = {  # rf_unknown
         RQ: r"^0[01]([0-9A-F]{10})?$",  # NOTE: RQ/07/10A0 has a payload
         EXPIRES: td(hours=4),
     },
+    _10B0: {  # unknown_10b0
+        NAME: "message_10b0",
+        RQ: r"^00$",
+        RP: r"^00[0-9A-F]{8}$",
+    },
     _10E0: {  # device_info
         NAME: "device_info",
         I_: r"^00[0-9A-F]{30,}$",  # r"^[0-9A-F]{32,}$" might be OK
@@ -294,6 +296,10 @@ RAMSES_CODES = {  # rf_unknown
         RQ: r"^(00|FC)([0-9A-F]{6}(00|FF)([0-9A-F]{4}01)?)?$",  # RQ/13:/00, or RQ/01:/FC:
         EXPIRES: td(days=1),
     },
+    _11F0: {  # unknown_11f0, from heatpump relay
+        NAME: "message_11f0",
+        I_: r"^00",
+    },
     _1260: {  # dhw_temp
         NAME: "dhw_temp",
         # RQ --- 30:185469 01:037519 --:------ 1260 001 00
@@ -307,20 +313,20 @@ RAMSES_CODES = {  # rf_unknown
     },
     _1280: {  # outdoor_humidity
         NAME: "outdoor_humidity",
-        I_: r"^00[0-9A-F]{10}$",
+        I_: r"^00[0-9A-F]{2}[0-9A-F]{8}?$",
     },
     _1290: {  # outdoor_temp
         NAME: "outdoor_temp",
         I_: r"^00[0-9A-F]{4}$",  # NOTE: RP is same
         RQ: r"^00$",
     },
-    _1298: {  # hvac_1298 - temperature/C?
+    _1298: {  # co2_level
         NAME: "hvac_1298",
         I_: r"^00[0-9A-F]{4}$",
     },
     _12A0: {  # indoor_humidity
         NAME: "indoor_humidity",
-        I_: r"^00[0-9A-F]{10}$",
+        I_: r"^00[0-9A-F]{2}[0-9A-F]{8}?$",  # TODO: (00)? at end - needs confirming
         EXPIRES: td(hours=1),
     },
     _12B0: {  # window_state  (HVAC % window open)
@@ -333,14 +339,20 @@ RAMSES_CODES = {  # rf_unknown
         NAME: "displayed_temp",  # displayed room temp
         I_: r"^00[0-9A-F]{2}0[01]$",
     },
-    _12C8: {  # hvac_12C8 - %?
-        NAME: "hvac_12C8",
+    _12C8: {  # unknown_12c8, HVAC
+        NAME: "hvac_12c8",
         I_: r"^0000[0-9A-F]{2}$",
     },
-    _12F0: {  # unknown
-        NAME: "message_12f0",
+    _12F0: {  # dhw_flow_rate
+        # 2021-11-05T06:25:20.399400 065 RP --- 10:023327 18:131597 --:------ 12F0 003 000307
+        # 2021-11-05T06:25:20.669382 066 RP --- 10:023327 18:131597 --:------ 3220 005 00C01307C0
+        # 2021-11-05T06:35:20.450201 065 RP --- 10:023327 18:131597 --:------ 12F0 003 000023
+        # 2021-11-05T06:35:20.721228 066 RP --- 10:023327 18:131597 --:------ 3220 005 0040130059
+        # 2021-12-06T06:35:54.575298 073 RP --- 10:051349 18:135447 --:------ 12F0 003 00059F
+        # 2021-12-06T06:35:55.949502 071 RP --- 10:051349 18:135447 --:------ 3220 005 00C0130ECC
+        NAME: "dhw_flow_rate",
         RQ: r"^00$",
-        RP: r"^00",
+        RP: r"^00[0-9A-F](4)$",
     },
     _1300: {  # cv water pressure (usu. for ch)
         NAME: "ch_pressure",
@@ -371,7 +383,14 @@ RAMSES_CODES = {  # rf_unknown
         I_: r"^((0[0-9A-F]|F[9ABCF])([0-9A-F]{10}))+$",
         W_: r"^((0[0-9A-F]|F[9ABCF])([0-9A-F]{10}))+$",
     },
-    _1FD0: {  # unknown
+    _1FCA: {  # unknown_1fca
+        NAME: "message_1fca",
+        RQ: r"^00$",
+        RP: r"^((0[0-9A-F]|F[9ABCF]|90)([0-9A-F]{10}))+$",  # xx-code-dev_id
+        I_: r"^((0[0-9A-F]|F[9ABCF])([0-9A-F]{10}))+$",
+        W_: r"^((0[0-9A-F]|F[9ABCF])([0-9A-F]{10}))+$",
+    },
+    _1FD0: {  # unknown_1fd0
         NAME: "message_1fd0",
         RQ: r"^00$",
         RP: r"^00",
@@ -391,9 +410,9 @@ RAMSES_CODES = {  # rf_unknown
         I_: r"^(0[0-9A-F][0-9A-F]{8}01){1,4}$",  # ~000A array, but max_len 24, not 48!
         # RP: Appear wont get any?,
     },
-    _22D0: {  # HVAC system switch
+    _22D0: {  # unknown_22d0, HVAC system switch?
         NAME: "message_22d0",
-        I_: r"^00000002$",  # TODO:
+        I_: r"^00",
     },
     _22D9: {  # boiler_setpoint
         NAME: "boiler_setpoint",
@@ -406,7 +425,7 @@ RAMSES_CODES = {  # rf_unknown
     },
     _22F3: {  # switch_duration
         NAME: "switch_duration",
-        I_: r"^0000[0-9A-F]{2}([0-9A-F]{8})?$",
+        I_: r"^00[0-9A-F]{4}([0-9A-F]{8})?$",
     },  # minutes
     _2309: {  # setpoint
         NAME: "setpoint",
@@ -426,32 +445,32 @@ RAMSES_CODES = {  # rf_unknown
         # RQ --- 22:070483 01:063844 --:------ 2349 007 06-0708-03-000027
         EXPIRES: td(hours=4),
     },
-    _2389: {  # unknown - CODE_IDX_COMPLEX?
+    _2389: {  # unknown_2389 - CODE_IDX_COMPLEX?
         #  I 024 03:052382 --:------ 03:052382 2389 003 02001B
         NAME: "unknown_2389",
         I_: r"^0[0-4][0-9A-F]{4}$",
     },
-    _2400: {  # unknown
+    _2400: {  # unknown_2400, from OTB
         NAME: "message_2400",
         RQ: r"^00$",
         RP: r"^00",
     },
-    _2401: {  # unknown
+    _2401: {  # unknown_2401, from OTB
         NAME: "message_2401",
         RQ: r"^00$",
         RP: r"^00",
     },
-    _2410: {  # unknown
+    _2410: {  # unknown_2410, from OTB
         NAME: "message_2410",
         RQ: r"^00$",
         RP: r"^00",
     },
-    _2420: {  # unknown
+    _2420: {  # unknown_2420, from OTB
         NAME: "message_2420",
         RQ: r"^00$",
         RP: r"^00",
     },
-    _2D49: {  # unknown
+    _2D49: {  # unknown_2d49
         NAME: "message_2d49",
         # 10:14:08.526 045  I --- 01:023389 --:------ 01:023389 2D49 003 010000
         # 10:14:12.253 047  I --- 01:023389 --:------ 01:023389 2D49 003 00C800
@@ -474,7 +493,7 @@ RAMSES_CODES = {  # rf_unknown
         RP: r"^0[0-9A-F][0-9A-F]{4}$",  # Null: r"^0[0-9A-F]7FFF$"
         EXPIRES: td(hours=1),
     },
-    _3120: {  # unknown - Error Report?
+    _3120: {  # unknown_3120 - Error Report?
         NAME: "message_3120",
         I_: r"^00[0-9A-F]{10}FF$",  # only ever: 34:/0070B0000000FF
         RQ: r"^00$",  # 20: will RP an RQ?
@@ -495,7 +514,7 @@ RAMSES_CODES = {  # rf_unknown
     _31D9: {  # ventilation_status
         NAME: "vent_status",
         # I_: r"^(00|21)[0-9A-F]{32}$",
-        I_: r"^(00|01|21)[0-9A-F]{4}([02]{28})?$",
+        I_: r"^(00|01|21)[0-9A-F]{4}(00(00|20){12}(00|08))?$",
         RQ: r"^00$",
     },
     _31DA: {  # ventilation_unknown
@@ -506,7 +525,7 @@ RAMSES_CODES = {  # rf_unknown
     },
     _31E0: {  # ext_ventilation - External Ventilation Status
         NAME: "ext_ventilation",
-        I_: r"^0000(00|C8)(00|FF)$",
+        I_: r"^0000(00|C8)(00|FF)$",  # TODO: final group is ? - needs confirming
     },
     _3200: {  # boiler output temp
         NAME: "boiler_output",
@@ -523,12 +542,12 @@ RAMSES_CODES = {  # rf_unknown
         RQ: r"^00[0-9A-F]{4}0{4}$",  # is strictly: r"^00[0-9A-F]{8}$",
         RP: r"^00[0-9A-F]{8}$",
     },
-    _3221: {  # unknown
+    _3221: {  # unknown_3221, from OTB
         NAME: "message_3221",
         RQ: r"^00$",
         RP: r"^00",
     },
-    _3223: {  # unknown
+    _3223: {  # unknown_3223, from OTB
         NAME: "message_3223",
         RQ: r"^00$",
         RP: r"^00",
@@ -675,6 +694,35 @@ _CODE_IDX_UNKNOWN.sort()  # or print(f"unknown = {_CODE_IDX_UNKNOWN}")
 # RAMSES_DEVICES
 #
 RAMSES_DEVICES_CLASS = {
+    DEV_KLASS.HGI: {  # HGI80: RF to (USB) serial gateway interface
+        _PUZZ: {I_: {}, RQ: {}, W_: {}},
+    },  # HGI80s can do what they like
+    DEV_KLASS.RFG: {  # RFG100: RF to Internet gateway (and others)
+        _0002: {RQ: {}},
+        _0004: {I_: {}, RQ: {}},
+        _0005: {RQ: {}},
+        _0006: {RQ: {}},
+        _000A: {RQ: {}},
+        _000C: {RQ: {}},
+        _000E: {W_: {}},
+        _0016: {RP: {}},
+        _0404: {RQ: {}, W_: {}},
+        _0418: {RQ: {}},
+        _10A0: {RQ: {}},
+        _10E0: {I_: {}, RQ: {}, RP: {}},
+        _1260: {RQ: {}},
+        _1290: {I_: {}},
+        _1F41: {RQ: {}},
+        _1FC9: {RP: {}, W_: {}},
+        _22D9: {RQ: {}},
+        _2309: {I_: {}},
+        _2349: {RQ: {}, RP: {}, W_: {}},
+        _2E04: {RQ: {}, I_: {}, W_: {}},
+        _30C9: {RQ: {}},
+        _313F: {RQ: {}, RP: {}, W_: {}},
+        _3220: {RQ: {}},
+        _3EF0: {RQ: {}},
+    },
     DEV_KLASS.CTL: {  # e.g. ATC928: Evohome Colour Controller
         _0001: {W_: {}},
         _0002: {I_: {}, RP: {}},
@@ -714,6 +762,97 @@ RAMSES_DEVICES_CLASS = {
         _3B00: {I_: {}},
         _3EF0: {RQ: {}},
     },
+    DEV_KLASS.PRG: {  # e.g. HCF82/HCW82: Room Temperature Sensor
+        _0009: {I_: {}},
+        _1090: {RP: {}},
+        _10A0: {RP: {}},
+        _1100: {I_: {}},
+        _1F09: {I_: {}},
+        _2249: {I_: {}},
+        _2309: {I_: {}},
+        _30C9: {I_: {}},
+        _3B00: {I_: {}},
+        _3EF1: {RP: {}},
+    },
+    DEV_KLASS.THM: {  # e.g. Generic Thermostat
+        _0001: {W_: {}},
+        _0005: {I_: {}},
+        _0008: {I_: {}},
+        _0009: {I_: {}},
+        _000A: {I_: {}, RQ: {}, W_: {}},
+        _000C: {I_: {}},
+        _000E: {I_: {}},
+        _0016: {RQ: {}},
+        _042F: {I_: {}},
+        _1030: {I_: {}},
+        _1060: {I_: {}},
+        _1090: {RQ: {}},
+        _10E0: {I_: {}},
+        _1100: {I_: {}},
+        _12C0: {I_: {}},
+        _1F09: {I_: {}},
+        _1FC9: {I_: {}},
+        _2309: {I_: {}, RQ: {}, W_: {}},
+        _2349: {RQ: {}, W_: {}},
+        _30C9: {I_: {}},
+        _3120: {I_: {}},
+        _313F: {I_: {}},  # W --- 30:253184 34:010943 --:------ 313F 009 006000070E0...
+        _3B00: {I_: {}},
+        _3EF0: {RQ: {}},  # when bound direct to a 13:
+        _3EF1: {RQ: {}},  # when bound direct to a 13:
+    },
+    # DEV_KLASS.RND: {  # e.g. TR87RF: Single (round) Zone Thermostat
+    #     _0005: {I_: {}},
+    #     _0008: {I_: {}},
+    #     _000A: {I_: {}, RQ: {}},
+    #     _000C: {I_: {}},
+    #     _000E: {I_: {}},
+    #     _042F: {I_: {}},
+    #     _1060: {I_: {}},
+    #     _10E0: {I_: {}},
+    #     _12C0: {I_: {}},
+    #     _1FC9: {I_: {}},
+    #     _2309: {I_: {}, RQ: {}, W_: {}},
+    #     _2349: {RQ: {}},
+    #     _30C9: {I_: {}},
+    #     _3120: {I_: {}},
+    #     _313F: {I_: {}},  # W --- 30:253184 34:010943 --:------ 313F 009 006000070E0...
+    #     _3EF0: {RQ: {}},  # when bound direct to a 13:
+    #     _3EF1: {RQ: {}},  # when bound direct to a 13:
+    # },
+    # DEV_KLASS.DTS: {  # e.g. DTS92(E)
+    #     _0001: {W_: {}},
+    #     _0008: {I_: {}},
+    #     _0009: {I_: {}},
+    #     _000A: {I_: {}, RQ: {}, W_: {}},
+    #     _0016: {RQ: {}},
+    #     # "0B04": {I_: {}},
+    #     _1030: {I_: {}},
+    #     _1060: {I_: {}},
+    #     _1090: {RQ: {}},
+    #     _1100: {I_: {}},
+    #     _1F09: {I_: {}},
+    #     _1FC9: {I_: {}},
+    #     _2309: {I_: {}, RQ: {}, W_: {}},
+    #     _2349: {RQ: {}, W_: {}},
+    #     _30C9: {I_: {}},
+    #     _313F: {I_: {}},
+    #     _3B00: {I_: {}},
+    #     _3EF1: {RQ: {}},
+    # },
+    # DEV_KLASS.HCW: {  # e.g. HCF82/HCW82: Room Temperature Sensor
+    #     _0001: {W_: {}},
+    #     _0002: {I_: {}},
+    #     _0008: {I_: {}},
+    #     _0009: {I_: {}},
+    #     _1060: {I_: {}},
+    #     _1100: {I_: {}},
+    #     _1F09: {I_: {}},
+    #     _1FC9: {I_: {}},
+    #     _2309: {I_: {}},
+    #     _2389: {I_: {}},
+    #     _30C9: {I_: {}},
+    # },
     DEV_KLASS.UFC: {  # e.g. HCE80/HCC80: Underfloor Heating Controller
         _0001: {RP: {}, W_: {}},  # TODO: Ix RP
         _0005: {RP: {}},
@@ -723,7 +862,6 @@ RAMSES_DEVICES_CLASS = {
         _10E0: {I_: {}, RP: {}},
         _22C9: {I_: {}},  # NOTE: No RP
         _22D0: {I_: {}, RP: {}},
-        _22F1: {I_: {}},
         _2309: {RP: {}},
         _3150: {I_: {}},
     },
@@ -767,7 +905,7 @@ RAMSES_DEVICES_CLASS = {
         _1300: {RP: {}},  # R8820A only?
         _1FC9: {I_: {}, W_: {}},
         _1FD0: {RP: {}},  # R8820A only?
-        _1FD4: {I_: {}},  # 2/min fro R8810, every ~210 sec for R8820
+        _1FD4: {I_: {}},  # 2/min for R8810, every ~210 sec for R8820
         _22D9: {RP: {}},
         _2400: {RP: {}},  # R8820A only?
         _2401: {RP: {}},  # R8820A only?
@@ -787,6 +925,7 @@ RAMSES_DEVICES_CLASS = {
         _0016: {RP: {}},
         # _10E0: {},  # 13: will not RP/10E0 # TODO: how to indicate that fact here
         _1100: {I_: {}, RP: {}},
+        _11F0: {I_: {}},  # BDR91T in heatpump mode
         _1FC9: {RP: {}, W_: {}},
         _3B00: {I_: {}},
         _3EF0: {I_: {}},
@@ -810,214 +949,89 @@ RAMSES_DEVICES_CLASS = {
         _3EF1: {RQ: {}, RP: {}},
     },
 }
-RAMSES_DEVICES = {
-    "03": {  # e.g. HCF82/HCW82: Room Temperature Sensor
-        _0001: {W_: {}},
-        _0002: {I_: {}},
-        _0008: {I_: {}},
-        _0009: {I_: {}},
-        _1060: {I_: {}},
-        _1100: {I_: {}},
-        _1F09: {I_: {}},
-        _1FC9: {I_: {}},
-        _2309: {I_: {}},
-        _2389: {I_: {}},
-        _30C9: {I_: {}},
-    },
-    "12": {  # DTS92(E): Digital Room Thermostat
-        _0001: {W_: {}},
-        _0008: {I_: {}},
-        _0009: {I_: {}},
-        _000A: {I_: {}, RQ: {}, W_: {}},
-        _0016: {RQ: {}},
-        # "0B04": {I_: {}},
-        _1030: {I_: {}},
-        _1060: {I_: {}},
-        _1090: {RQ: {}},
-        _1100: {I_: {}},
-        _1F09: {I_: {}},
-        _1FC9: {I_: {}},
-        _2309: {I_: {}, RQ: {}, W_: {}},
-        _2349: {RQ: {}, W_: {}},
-        _30C9: {I_: {}},
-        _313F: {I_: {}},
-        _3B00: {I_: {}},
-        _3EF1: {RQ: {}},
-    },
-    "18": {  # HGI80: RF to (USB) serial gateway interface
-        _PUZZ: {I_: {}, RQ: {}, W_: {}},
-    },  # HGI80s can do what they like
-    "23": {
-        _0009: {I_: {}},
-        _1090: {RP: {}},
-        _10A0: {RP: {}},
-        _1100: {I_: {}},
-        _1F09: {I_: {}},
-        _2249: {I_: {}},
-        _2309: {I_: {}},
-        _30C9: {I_: {}},
-        _3B00: {I_: {}},
-        _3EF1: {RP: {}},
-    },
-    "30": {  # RFG100: RF to Internet gateway (and others)
-        # RFG:185469 - Honeywell RFG100
-        _0002: {RQ: {}},
-        _0004: {I_: {}, RQ: {}},
-        _0005: {RQ: {}},
-        _0006: {RQ: {}},
-        _000A: {RQ: {}},
-        _000C: {RQ: {}},
-        _000E: {W_: {}},
-        _0016: {RP: {}},
-        _0404: {RQ: {}, W_: {}},
-        _0418: {RQ: {}},
-        _10A0: {RQ: {}},
-        _10E0: {I_: {}, RQ: {}, RP: {}},
-        _1260: {RQ: {}},
-        _1290: {I_: {}},
-        _1F41: {RQ: {}},
-        _1FC9: {RP: {}, W_: {}},
-        _22D9: {RQ: {}},
-        _2309: {I_: {}},
-        _2349: {RQ: {}, RP: {}, W_: {}},
-        _2E04: {RQ: {}, I_: {}, W_: {}},
-        _30C9: {RQ: {}},
-        _313F: {RQ: {}, RP: {}, W_: {}},
-        _3220: {RQ: {}},
-        _3EF0: {RQ: {}},
-        # VMS:082155 - HVAC: Nuaire Ventilation
-        # _10E0: {I_: {}, RP: {},},
-        _1F09: {I_: {}, RP: {}},
-        _31D9: {I_: {}},
-        _31DA: {I_: {}, RP: {}},
-    },
-    "34": {  # e.g. TR87RF: Single (round) Zone Thermostat
-        _0005: {I_: {}},
-        _0008: {I_: {}},
-        _000A: {I_: {}, RQ: {}},
-        _000C: {I_: {}},
-        _000E: {I_: {}},
-        _042F: {I_: {}},
-        _1060: {I_: {}},
-        _10E0: {I_: {}},
-        _12C0: {I_: {}},
-        _1FC9: {I_: {}},
-        _2309: {I_: {}, RQ: {}, W_: {}},
-        _2349: {RQ: {}},
-        _30C9: {I_: {}},
-        _3120: {I_: {}},
-        _313F: {I_: {}},  # W --- 30:253184 34:010943 --:------ 313F 009 006000070E0...
-        _3EF0: {RQ: {}},  # when bound direct to a 13:
-        _3EF1: {RQ: {}},  # when bound direct to a 13:
-    },
-}
-RAMSES_DEVICES["00"] = RAMSES_DEVICES_CLASS["TRV"]  # HR80
-RAMSES_DEVICES["21"] = RAMSES_DEVICES["34"]  # T87RF1003
-RAMSES_DEVICES["22"] = RAMSES_DEVICES["12"]  # DTS92
 
-HVAC_DEVICES = {
-    "20": {  # HVAC: ventilation unit, or switch/sensor?
-        _10E0: {I_: {}, RP: {}},
-        _12A0: {RP: {}},
-        _22F1: {I_: {}},
-        _22F3: {I_: {}},
-        _3120: {RP: {}},
-        _31D9: {I_: {}, RP: {}},
-        _31DA: {I_: {}},
-    },  # e.g. https://www.ithodaalderop.nl/nl-NL/professional/product/545-5036
-    "29": {  # HVAC: Orcon MVS-15RP / MVS-15LF (vent mech. control)
-        _10E0: {I_: {}},  # VMC-15RP01 / VMN-15LF01
-        _31D9: {I_: {}},
-    },  # e.g. https://www.orcon.nl/blueline-mvs-15rp-2/
-    "32": {  # HVAC: switch/sensor?
-        _042F: {I_: {}},
-        _1060: {I_: {}},
+HVAC_DEVICES_CLASS = {
+    DEV_KLASS.FAN: {
         _10E0: {I_: {}, RP: {}},
         _1298: {I_: {}},
         _12A0: {I_: {}},
-        _22F1: {I_: {}},
+        _12C8: {I_: {}},
+        _1F09: {I_: {}, RP: {}},
+        _3120: {I_: {}},
+        _313F: {I_: {}},
+        _31D9: {I_: {}},
+        _31DA: {I_: {}, RP: {}},
+        # _31E0: {I_: {}},
+    },
+    DEV_KLASS.CO2: {
+        _042F: {I_: {}},
+        _10E0: {I_: {}, RP: {}},
+        _1298: {I_: {}},
         _31DA: {RQ: {}},
         _31E0: {I_: {}},
     },
-    "37": {  # HVAC: ventilation unit
-        _10E0: {I_: {}, RP: {}},
-        _1298: {I_: {}},
-        _12C8: {I_: {}},
-        _3120: {I_: {}},
-        _31D9: {I_: {}},
-        _31DA: {I_: {}},
+    DEV_KLASS.HUM: {
+        _1060: {I_: {}},
+        _10E0: {I_: {}},
+        _12A0: {I_: {}},
+        _31DA: {RQ: {}},
+        _31E0: {I_: {}},
     },
-    "39": {  # HVAC: two-way switch; also an "06/22F1"?
+    DEV_KLASS.SWI: {  # HVAC: two-way switch; also an "06/22F1"?
+        _1060: {I_: {}},
+        _10E0: {I_: {}},
         _22F1: {I_: {}},
         _22F3: {I_: {}},
+        # _31E0: {I_: {}},
     },  # https://www.ithodaalderop.nl/nl-NL/professional/product/536-0124
 }
 
-RAMSES_DEVICES = {**HVAC_DEVICES, **RAMSES_DEVICES}
-for k, v in DEVICE_TYPE_BY_CLASS.items():
-    if k in RAMSES_DEVICES_CLASS:
-        RAMSES_DEVICES[v] = RAMSES_DEVICES_CLASS[k]
+# RAMSES_DEVICES = {**HVAC_DEVICES, **RAMSES_DEVICES}
+# for k, v in DEVICE_TYPE_BY_CLASS.items():
+#     if k in RAMSES_DEVICES_CLASS:
+#         RAMSES_DEVICES[v] = RAMSES_DEVICES_CLASS[k]
+
+RAMSES_DEVICES = {**HVAC_DEVICES_CLASS, **RAMSES_DEVICES_CLASS}
 
 
-##############
+####################
 # RAMSES_ZONES (WIP)
 #
-RAMSES_ZONES = {
-    "ALL": {
-        _0004: {I_: {}, RP: {}},
-        _000C: {RP: {}},
-        _000A: {I_: {}, RP: {}},
-        _2309: {I_: {}, RP: {}},
-        _2349: {I_: {}, RP: {}},
-        _30C9: {I_: {}, RP: {}},
-    },
-    "RAD": {
-        _12B0: {I_: {}, RP: {}},
-        "3150a": {},
-    },
-    "ELE": {
-        _0008: {I_: {}},
-        _0009: {I_: {}},
-    },
-    "VAL": {
-        _0008: {I_: {}},
-        _0009: {I_: {}},
-        "3150a": {},
-    },
-    "UFH": {
-        _3150: {I_: {}},
-    },
-    "MIX": {
-        _0008: {I_: {}},
-        "3150a": {},
-    },
-    "DHW": {
-        _10A0: {RQ: {}, RP: {}},
-        _1260: {I_: {}},
-        _1F41: {I_: {}},
-    },
-}
-RAMSES_ZONES_ALL = RAMSES_ZONES.pop("ALL")
-RAMSES_ZONES_DHW = RAMSES_ZONES["DHW"]
-[RAMSES_ZONES[k].update(RAMSES_ZONES_ALL) for k in RAMSES_ZONES if k != "DHW"]
-
-
-# _DEVICE_SIGNATURES = {
-#     "CTL": ((_0100, I_), (_0100, RP), (_0404, I_), (_0404, RP), (_0418, I_), (_0418, RP), ),
-#     "UFC": (),
-#     "DHW": ((_1260, I_)),
-#     "BDR": (),
-#     "OTB": ((_3220, RP)),
-#     "EXT": (),  # OUT?
-#     "RFG": (),
-#     "VNS": (),
-#     "VNT": ((_31D9, I_), (_31D9, RP), (_31DA, I_), (_31DA, RP)),
+# RAMSES_ZONES = {
+#     "ALL": {
+#         _0004: {I_: {}, RP: {}},
+#         _000C: {RP: {}},
+#         _000A: {I_: {}, RP: {}},
+#         _2309: {I_: {}, RP: {}},
+#         _2349: {I_: {}, RP: {}},
+#         _30C9: {I_: {}, RP: {}},
+#     },
+#     "RAD": {
+#         _12B0: {I_: {}, RP: {}},
+#         "3150a": {},
+#     },
+#     "ELE": {
+#         _0008: {I_: {}},
+#         _0009: {I_: {}},
+#     },
+#     "VAL": {
+#         _0008: {I_: {}},
+#         _0009: {I_: {}},
+#         "3150a": {},
+#     },
+#     "UFH": {
+#         _3150: {I_: {}},
+#     },
+#     "MIX": {
+#         _0008: {I_: {}},
+#         "3150a": {},
+#     },
+#     "DHW": {
+#         _10A0: {RQ: {}, RP: {}},
+#         _1260: {I_: {}},
+#         _1F41: {I_: {}},
+#     },
 # }
-
-# DEVICE_SIGNATURES = {}
-# for device, signatures in _DEVICE_SIGNATURES.items():
-#     for pair in signatures:
-#         if (code := pair[1]) in DEVICE_SIGNATURES:
-#             raise RuntimeError
-#         else:
-#             DEVICE_SIGNATURES[device] = {code: pair[0]}
+# RAMSES_ZONES_ALL = RAMSES_ZONES.pop("ALL")
+# RAMSES_ZONES_DHW = RAMSES_ZONES["DHW"]
+# [RAMSES_ZONES[k].update(RAMSES_ZONES_ALL) for k in RAMSES_ZONES if k != "DHW"]
