@@ -3,7 +3,11 @@
 #
 """RAMSES RF - The evohome-compatible zones."""
 
+# Kudos & many thanks to:
+# - dbmandrake: valve poaition -> heat demand transform
+
 import logging
+import math
 from asyncio import Task
 from datetime import datetime as dt
 from datetime import timedelta as td
@@ -63,6 +67,7 @@ from .protocol import (  # noqa: F401, isort: skip
     _000E,
     _0016,
     _0100,
+    _0150,
     _01D0,
     _01E9,
     _0404,
@@ -71,9 +76,13 @@ from .protocol import (  # noqa: F401, isort: skip
     _0B04,
     _1030,
     _1060,
+    _1081,
     _1090,
+    _1098,
     _10A0,
+    _10B0,
     _10E0,
+    _10E1,
     _1100,
     _1260,
     _1280,
@@ -83,9 +92,12 @@ from .protocol import (  # noqa: F401, isort: skip
     _12B0,
     _12C0,
     _12C8,
+    _12F0,
+    _1300,
     _1F09,
     _1F41,
     _1FC9,
+    _1FD0,
     _1FD4,
     _2249,
     _22C9,
@@ -95,6 +107,11 @@ from .protocol import (  # noqa: F401, isort: skip
     _22F3,
     _2309,
     _2349,
+    _2389,
+    _2400,
+    _2401,
+    _2410,
+    _2420,
     _2D49,
     _2E04,
     _30C9,
@@ -104,7 +121,11 @@ from .protocol import (  # noqa: F401, isort: skip
     _31D9,
     _31DA,
     _31E0,
+    _3200,
+    _3210,
     _3220,
+    _3221,
+    _3223,
     _3B00,
     _3EF0,
     _3EF1,
@@ -119,7 +140,8 @@ if DEV_MODE:
 
 
 ZON_KLASS = SimpleNamespace(
-    DHW="DHW",  # Stored HW (not a zone)
+    # ZON="ZON",  # Generic (promotable) zone
+    DHW="DHW",  # Stored HW (not a classic zone)
     ELE="ELE",  # Electric
     MIX="MIX",  # Mix valve
     RAD="RAD",  # Radiator
@@ -131,7 +153,7 @@ ZON_KLASS = SimpleNamespace(
 class ZoneBase(Entity):
     """The Zone/DHW base class."""
 
-    # _klass = None  # NOTE: this would cause problems
+    # _ZON_KLASS = None
 
     def __init__(self, evo, zone_idx) -> None:
         _LOGGER.debug("Creating a Zone: %s_%s (%s)", evo, zone_idx, self.__class__)
@@ -194,7 +216,7 @@ class ZoneBase(Entity):
     @property
     def heating_type(self) -> Optional[str]:
         """Return the type of the zone/DHW (e.g. electric_zone, stored_dhw)."""
-        return self._klass
+        return self._ZON_KLASS
 
 
 class ZoneSchedule:  # 0404  # TODO: add for DHW
@@ -269,7 +291,7 @@ class RelayDemand:  # 0008
 class DhwZone(ZoneSchedule, ZoneBase):  # CS92A  # TODO: add Schedule
     """The DHW class."""
 
-    _klass = ZON_KLASS.DHW
+    _ZON_KLASS = ZON_KLASS.DHW
 
     def __init__(
         self, ctl, zone_idx="HW", sensor=None, dhw_valve=None, htg_valve=None
@@ -513,7 +535,7 @@ class DhwZone(ZoneSchedule, ZoneBase):  # CS92A  # TODO: add Schedule
 class Zone(ZoneSchedule, ZoneBase):
     """The Zone class for all zone types (but not DHW)."""
 
-    _klass = None  # Unknown
+    _ZON_KLASS = None  # Unknown
 
     def __init__(self, evo, zone_idx, sensor=None, actuators=None) -> None:
         """Create a zone.
@@ -706,7 +728,7 @@ class Zone(ZoneSchedule, ZoneBase):
         """
 
         _type = ZONE_TYPE_SLUGS.get(zone_type, zone_type)
-        if _type not in _ZON_CLASS_BY_KLASS:
+        if _type not in _ZON_BY_KLASS:
             raise ValueError(f"Not a known zone_type: {zone_type}")
 
         if self._zone_type == _type:
@@ -719,7 +741,7 @@ class Zone(ZoneSchedule, ZoneBase):
             )
 
         self._zone_type = _type
-        self.__class__ = _ZON_CLASS_BY_KLASS[_type]
+        self.__class__ = _ZON_BY_KLASS[_type]
         self._discover(discover_flag=Discover.ALL)  # TODO: needs tidyup (ref #67)
         _LOGGER.debug("Promoted a Zone: %s(%s)", self.id, self.__class__)
 
@@ -765,8 +787,7 @@ class Zone(ZoneSchedule, ZoneBase):
             for d in self.devices
             if hasattr(d, ATTR_HEAT_DEMAND) and d.heat_demand is not None
         ]
-        # return round(sum(demands) / len(demands), 1) if demands else None
-        return max(demands + [0]) if demands else None
+        return _transform(max(demands + [0])) if demands else None
 
     @property
     def window_open(self) -> Optional[bool]:  # 12B0  # TODO: don't work >1 TRV?
@@ -865,7 +886,7 @@ class Zone(ZoneSchedule, ZoneBase):
 class EleZone(RelayDemand, Zone):  # BDR91A/T  # TODO: 0008/0009/3150
     """For a small electric load controlled by a relay (never calls for heat)."""
 
-    _klass = ZON_KLASS.ELE
+    _ZON_KLASS = ZON_KLASS.ELE
 
     # def __init__(self, *args, **kwargs) -> None:  # can't use this here
 
@@ -891,9 +912,9 @@ class EleZone(RelayDemand, Zone):  # BDR91A/T  # TODO: 0008/0009/3150
             raise TypeError("WHAT 2")
 
     @property
-    def heat_demand(self) -> None:  # Electric zones (do *not* call for heat)
-        """Return None as the zone's heat demand, electric zones don't call for heat."""
-        return
+    def heat_demand(self) -> Optional[float]:
+        """Return 0 as the zone's heat demand, as electric zones don't call for heat."""
+        return 0
 
 
 class MixZone(Zone):  # HM80  # TODO: 0008/0009/3150
@@ -902,7 +923,7 @@ class MixZone(Zone):  # HM80  # TODO: 0008/0009/3150
     Note that HM80s are listen-only devices.
     """
 
-    _klass = ZON_KLASS.MIX
+    _ZON_KLASS = ZON_KLASS.MIX
 
     # def __init__(self, *args, **kwargs) -> None:  # can't use this here
 
@@ -935,7 +956,7 @@ class MixZone(Zone):  # HM80  # TODO: 0008/0009/3150
 class RadZone(Zone):  # HR92/HR80
     """For radiators controlled by HR92s or HR80s (will also call for heat)."""
 
-    _klass = ZON_KLASS.RAD
+    _ZON_KLASS = ZON_KLASS.RAD
 
     # def __init__(self, *args, **kwargs) -> None:  # can't use this here
 
@@ -954,7 +975,7 @@ class RadZone(Zone):  # HR92/HR80
 class UfhZone(Zone):  # HCC80/HCE80  # TODO: needs checking
     """For underfloor heating controlled by an HCE80/HCC80 (will also call for heat)."""
 
-    _klass = ZON_KLASS.UFH
+    _ZON_KLASS = ZON_KLASS.UFH
 
     # def __init__(self, *args, **kwargs) -> None:  # can't use this here
 
@@ -989,7 +1010,7 @@ class UfhZone(Zone):  # HCC80/HCE80  # TODO: needs checking
 class ValZone(EleZone):  # BDR91A/T
     """For a motorised valve controlled by a BDR91 (will also call for heat)."""
 
-    _klass = ZON_KLASS.VAL
+    _ZON_KLASS = ZON_KLASS.VAL
 
     # def __init__(self, *args, **kwargs) -> None:  # can't use this here
 
@@ -1010,23 +1031,40 @@ class ValZone(EleZone):  # BDR91A/T
         return self.relay_demand
 
 
-_ZON_CLASS_BY_KLASS = class_by_attr(__name__, "_klass")  # e.g. "RAD": RadZone
+def _transform(valve_pos: float) -> float:
+    """Transform a valve position into a heat demand, as displayed in the evohome UI."""
+    # import math
+    valve_pos = valve_pos * 100
+    if valve_pos <= 30:
+        return 0
+    t0, t1, t2 = (0, 30, 70) if valve_pos <= 70 else (30, 70, 100)
+    return math.floor((valve_pos - t1) * t1 / (t2 - t1) + t0 + 0.5) / 100
 
 
-def create_zone(evo, zone_idx: str, profile=None, **kwargs) -> Zone:
+def test_transform() -> None:
+    valve_pos_list = [0, 0.26, 0.30, 0.34, 0.43, 0.45, 0.48, 0.53, 0.69, 0.70, 1]
+    heat_demand_list = [0, 0, 0, 0.03, 0.10, 0.11, 0.14, 0.17, 0.29, 0.30, 1]
+    print("v_pos\tevohome\tdemand\tmatch")
+    for valve_pos, heat_demand in zip(valve_pos_list, heat_demand_list):
+        result = _transform(valve_pos)
+        status = "OK" if result == heat_demand else "Failed!"
+        print(valve_pos, "\t", heat_demand, "\t", result, "\t", status)
+
+
+_ZON_BY_KLASS = class_by_attr(__name__, "_ZON_KLASS")  # e.g. "RAD": RadZone
+
+
+def create_zone(evo, zone_idx: str, klass=None, **kwargs) -> Zone:
     """Create a zone, and optionally perform discovery & start polling."""
 
-    #
+    if klass is None:
+        klass = ZON_KLASS.DHW if zone_idx == "HW" else None
 
-    if profile is None:
-        profile = ZON_KLASS.DHW if zone_idx == "HW" else None
-        #
-        #
-        #
+    zone = _ZON_BY_KLASS.get(klass, Zone)(evo, zone_idx, **kwargs)
 
-    zone = _ZON_CLASS_BY_KLASS.get(profile, Zone)(evo, zone_idx, **kwargs)
-
-    if isinstance(evo._gwy.pkt_protocol, PacketProtocolPort):
+    if not evo._gwy.config.disable_discovery and isinstance(
+        evo._gwy.pkt_protocol, PacketProtocolPort
+    ):
         zone._start_discovery()
 
     return zone
